--author: igor29381
--v1.0
--date 28.06.17

Helper = {};

local Helper_mt = Class(Helper);

function Helper:new(id)
	local self = {};
	setmetatable(self, Helper_mt);
	self.rootNode = id;
	self.nodes = {};
	local numChild = getNumOfChildren(id);
	if numChild > 0 then
		for i=1, numChild do
			local node = getChildAt(id, i-1);
			table.insert(self.nodes, node);
		end;
	else
		table.insert(self.nodes, id);
	end;
	return self;
end;

function Helper:delete()
end;

function Helper:update(dt)
	local vis = getVisibility(self.nodes[1]);
	if Kavkaz and Kavkaz.UniversalFactoryHUD then
		if not Kavkaz.UniversalFactoryHUD.settings[Kavkaz.UniversalFactoryHUD.SET_HELPSTRINGS] then
			if vis then
				self:setHelperVisibility(false);
			end;
		elseif not vis then
			self:setHelperVisibility(true);
		end;
	else
		if g_gameSettings:getValue("showHelpMenu") then
			if not vis then
				self:setHelperVisibility(true);
			end;
		elseif vis then
			self:setHelperVisibility(false);
		end;
	end;
	if not g_gui:getIsGuiVisible() then
		if Kavkaz and Kavkaz.UniversalFactoryHUD then
			if (not Kavkaz.UniversalFactoryHUD.settings[Kavkaz.UniversalFactoryHUD.SET_HELPSTRINGS]
			or Kavkaz.Economica.active or Kavkaz.Economica.showMessage) then
				return;
			end;
		elseif not g_gameSettings:getValue("showHelpMenu") then
			return;
		end;
		local x,y,z = self:getNearestHelperPosition();
		if x and y and z then
			local sx,sy,sz = project(x,y+0.5,z);
			if sz <= 1 and sx < 0.75 and sx > 0.25 then
				setTextAlignment(RenderText.ALIGN_CENTER);
				setTextBold(false);
				setTextColor(1, 1, 1, 0.5);
				if self.text1 then
					renderText(sx, sy+0.04, getCorrectTextSize(0.02), self.text1);
				end;
				if self.text2 then
					renderText(sx, sy+0.02, getCorrectTextSize(0.02), self.text2);
				end;
				setTextColor(1, 1, 1, 1);
				setTextAlignment(RenderText.ALIGN_LEFT);
			end;
		end;
	end;
end;

function Helper:getNearestHelperPosition()
	local cx,cy,cz = getWorldTranslation(getCamera());
	local nx,ny,nz = getWorldTranslation(self.rootNode);
	local baseDistance = Utils.vector3Length(cx-nx,cy-ny,cz-nz);
	if baseDistance < 30 then
		for i=1, #self.nodes do
			local hx,hy,hz = getWorldTranslation(self.nodes[i]);
			if Utils.vector3Length(cx-hx,cy-hy,cz-hz) <= baseDistance then
				return hx,hy,hz;
			end;
		end;
	end;
end;

function Helper:setHelperVisibility(state)
	for i=1, #self.nodes do
		setVisibility(self.nodes[i], state);
	end;
end;
